@@ -1,8 +1,7 @@
 /**********************************************************************
- * $Id: Polygonal.h 3232 2011-02-22 21:22:19Z strk $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2011  Sandro Santilli <strk@keybit.net>
  *
@@ -23,6 +22,11 @@
 #include <geos/export.h>
 #include <geos/geom/Geometry.h> // for inheritance
 
+#ifdef _MSC_VER
+#pragma warning(push)
+#pragma warning(disable: 4589) // warning C4589 : Constructor of abstract class 'Puntal' ignores initializer for virtual base class 'Geometry'
+#endif
+
 namespace geos {
 namespace geom { // geos::geom
 
@@ -39,4 +43,8 @@ protected:
 } // namespace geos::geom
 } // namespace geos
 
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
+
 #endif // ndef GEOS_GEOM_POLYGONAL_H
